/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'lv', {
	border: 'Rādīt rāmi',
	noUrl: 'Norādiet iframe adresi',
	scrolling: 'Atļaut ritjoslas',
	title: 'IFrame uzstādījumi',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
